@@ -465,6 +465,7 @@ ECHO384 = ContainerType(
         "dispense",
         "cover",
         "provision",
+        "acoustic_transfer",
     ],
     shortname="384-echo",
     col_count=24,
@@ -1166,10 +1167,48 @@ ROUND384LV = ContainerType(
     col_count=24,
     dead_volume_ul=Unit(2, "microliter"),
     safe_min_volume_ul=Unit(2, "microliter"),
+    true_max_vol_ul=Unit(35, "microliter"),
     vendor="Corning",
     cat_no="4513",
 )
 
+#:
+ROUND384LVNC = ContainerType(
+    name="384-well round-bottom low-volume Corning-4512 plate",
+    well_count=384,
+    well_depth_mm=6.58,
+    well_volume_ul=Unit(20.0, "microliter"),
+    well_coating="nonbinding_surface",
+    sterile=False,
+    is_tube=False,
+    cover_types=["universal", "standard"],
+    seal_types=["ultra-clear", "foil"],
+    capabilities=[
+        "incubate",
+        "seal",
+        "deseal",
+        "liquid_handle",
+        "dispense",
+        "spin",
+        "fluorescence",
+        "cover",
+        "uncover",
+        "echo_dest",
+        "stamp",
+        "transfer",
+        "provision",
+        "pipette",
+        "envision",
+    ],
+    shortname="384-corning-4512-round-lv",
+    col_count=24,
+    dead_volume_ul=Unit(2, "microliter"),
+    safe_min_volume_ul=Unit(2, "microliter"),
+    true_max_vol_ul=Unit(35, "microliter"),
+    vendor="Corning",
+    cat_no="4512",
+)
+
 #:
 RESSW384LP = ContainerType(
     name="384-well singlewell lowprofile reservoir",
@@ -1219,6 +1258,7 @@ ECHO384LDV = ContainerType(
         "dispense",
         "cover",
         "provision",
+        "acoustic_transfer",
     ],
     shortname="384-echo-ldv",
     col_count=24,
@@ -1248,6 +1288,7 @@ ECHO384LDVPLUS = ContainerType(
         "dispense",
         "cover",
         "provision",
+        "acoustic_transfer",
     ],
     shortname="384-echo-ldv-plus",
     col_count=24,
@@ -1277,6 +1318,7 @@ ECHO1536LDV = ContainerType(
         "dispense",
         "cover",
         "provision",
+        "acoustic_transfer",
     ],
     shortname="1536-echo-ldv-beckman-001-6969",
     col_count=48,
@@ -1601,6 +1643,7 @@ _CONTAINER_TYPES = {
     "384-round-clear-clear": ROUND384CLEAR,
     "res-sw384-lp": RESSW384LP,
     "384-corning-4513-round-lv": ROUND384LV,
+    "384-corning-4512-round-lv": ROUND384LVNC,
     "384-echo-ldv": ECHO384LDV,
     "384-echo-ldv-plus": ECHO384LDVPLUS,
     "1536-echo-ldv-beckman-001-6969": ECHO1536LDV,
